@@ -34,12 +34,12 @@ def time_serie(ts_code: int, start: str, end: str, strict: bool = False) -> pd.S
         2018-01-05    0.026444
         2018-01-08    0.026444
     """
-    
+
     if strict:
         ts_data = api.get_data_with_strict_range(ts_code, start, end)
     else:
         ts_data = api.get_data(ts_code, start, end)
-        
+
     values = []
     index = []
     for i in ts_data:
@@ -48,4 +48,4 @@ def time_serie(ts_code: int, start: str, end: str, strict: bool = False) -> pd.S
 
     # Transform empty strings in null values
     values = [np.nan if value == "" else value for value in values]
-    return pd.Series(values, index, name=ts_code, dtype=np.float)
+    return pd.Series(values, index, name=ts_code, dtype=np.float64)  # type: ignore
